@@ -11,23 +11,13 @@
 # This script based on https://github.com/rocky/python-uncompyle6/blob/master/__pkginfo__.py
 #
 
-# stdlib
-import pathlib
-
 __all__ = [
-		"__copyright__",
 		"__version__",
-		"repo_root",
-		"install_requires",
 		"extras_require",
 		]
 
-__copyright__ = """
-2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
-"""
-
-__version__ = "0.5.1"
-
-repo_root = pathlib.Path(__file__).parent
-install_requires = (repo_root / "requirements.txt").read_text(encoding="utf-8").split('\n')
-extras_require = {"all": []}
+__version__ = "1.0.0"
+extras_require = {
+		"limiter": ["cachecontrol[filecache]>=0.12.6", "lockfile>=0.12.2"],
+		"all": ["cachecontrol[filecache]>=0.12.6", "lockfile>=0.12.2"]
+		}
