@@ -24,24 +24,16 @@ Handy tools for working with URLs and APIs.
 #
 
 # this package
-from apeye import cache, rate_limiter
-from apeye.requests_url import RequestsURL, TrailingRequestsURL
-from apeye.slumber_url import SlumberURL
 from apeye.url import URL, Domain, URLPath
 
 __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020 Dominic Davis-Foster"
 __license__: str = "GNU Lesser General Public License v3 or later (LGPLv3+)"
-__version__: str = "0.5.1"
+__version__: str = "1.0.0"
 __email__: str = "dominic@davis-foster.co.uk"
 
 __all__ = [
 		"URL",
 		"Domain",
 		"URLPath",
-		"RequestsURL",
-		"TrailingRequestsURL",
-		"SlumberURL",
-		"cache",
-		"rate_limiter",
 		]
