@@ -3,9 +3,13 @@
 #  rate_limiter.py
 """
 Rate limiters for making calls to external APIs in a polite manner.
+
+.. extras-require:: limiter
+	:pyproject:
+
 """
 #
-#  Copyright (c) 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
+#  Copyright (c) 2020-2021 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU Lesser General Public License as published by
@@ -39,14 +43,13 @@ from functools import wraps
 from typing import Any, Callable, Dict, Optional
 
 # 3rd party
-import appdirs  # type: ignore
+import appdirs
 # import codetiming
 import requests
-from cachecontrol import CacheControl, CacheControlAdapter  # type: ignore
-from cachecontrol.caches.file_cache import FileCache  # type: ignore
-from cachecontrol.heuristics import ExpiresAfter  # type: ignore
+from cachecontrol import CacheControl, CacheControlAdapter  # type: ignore  # nodep
+from cachecontrol.caches.file_cache import FileCache  # type: ignore  # nodep
+from cachecontrol.heuristics import ExpiresAfter  # type: ignore  # nodep
 from domdf_python_tools.paths import PathPlus
-from requests import PreparedRequest
 
 __all__ = [
 		"rate_limit",
@@ -54,6 +57,12 @@ __all__ = [
 		"HTTPCache",
 		]
 
+# Fixes intersphinx links
+requests.PreparedRequest.__module__ = "requests"
+requests.Response.__module__ = "requests"
+requests.Request.__module__ = "requests"
+requests.Session.__module__ = "requests"
+
 
 def rate_limit(min_time: float = 0.2, logger: Optional[logging.Logger] = None) -> Callable[[Callable], Any]:
 	"""
@@ -61,9 +70,9 @@ def rate_limit(min_time: float = 0.2, logger: Optional[logging.Logger] = None) -
 	Used for rate limiting.
 
 	:param min_time: The minimum interval between subsequent runs of the decorated function.
-	:default min_time: ``0.2``, which gives a maximum rate of 5 calls per second.
+	:default min_time: ``0.2``, which gives a maximum rate of 5 calls per second
 	:param logger: Optional logger to log information about requests to. Defaults to the root logger.
-	:no default logger:
+	:no-default logger:
 	"""
 
 	if logger is None:
@@ -75,8 +84,8 @@ def rate_limit(min_time: float = 0.2, logger: Optional[logging.Logger] = None) -
 	def decorator(func: Callable) -> Callable:
 
 		function_name = func.__name__
-		last_ran_message = f"{function_name}: Last ran %d seconds ago."
-		waiting_message = f"{function_name}: Waiting %d seconds."
+		last_ran_message = f"{function_name}: Last ran %.2f seconds ago."
+		waiting_message = f"{function_name}: Waiting %.2f seconds."
 
 		@wraps(func)
 		def rate_limit_wrapper(*args, **kwargs):
@@ -102,8 +111,8 @@ def rate_limit(min_time: float = 0.2, logger: Optional[logging.Logger] = None) -
 
 
 class RateLimitAdapter(CacheControlAdapter):
-	"""
-	Custom :class:`CacheControl.CacheControlAdapter` to limit the rate of requests to 5 per second.
+	r"""
+	Custom :class:`~.CacheControlAdapter` to limit the rate of requests to 5 per second.
 
 	:param cache:
 	:param cache_etags:
@@ -111,17 +120,20 @@ class RateLimitAdapter(CacheControlAdapter):
 	:param serializer:
 	:param heuristic:
 	:param cacheable_methods:
+
+	.. autosummary-widths:: 7/16
 	"""
 
-	def send(self, request: PreparedRequest, cacheable_methods=None, **kwargs) -> requests.Response:
-		"""
-		Send a request. Use the request information to see if it
-		exists in the cache and cache the response if we need to and can.
+	def send(self, request: requests.PreparedRequest, cacheable_methods=None, **kwargs) -> requests.Response:
+		r"""
+		Send a request.
 
-		:param request: The :class:`requests.models.PreparedRequest` being sent.
+		Use the request information to see if it exists in the cache and cache the response if we need to and can.
+
+		:param request: The :class:`requests.PreparedRequest` being sent.
 		:param cacheable_methods:
-		:param kwargs: Additional arguments take by :meth:`requests.adapters.HTTPAdapter.send`.
-		"""  # noqa: D400
+		:param \*\*kwargs: Additional arguments take by :meth:`requests.adapters.HTTPAdapter.send`.
+		"""
 
 		cacheable = cacheable_methods or self.cacheable_methods
 		if request.method in cacheable:
@@ -142,11 +154,11 @@ class RateLimitAdapter(CacheControlAdapter):
 	@rate_limit(0.2)
 	def rate_limited_send(self, *args, **kwargs) -> requests.Response:
 		"""
-		Wrapper around :meth:`CacheControl.CacheControlAdapter.send` to limit the
-		rate of requests.
+		Wrapper around :meth:`CacheControlAdapter.send <CacheControl.CacheControlAdapter.send>`
+		to limit the rate of requests.
 		"""  # noqa: D400
 
-		return super(CacheControlAdapter, self).send(*args, **kwargs)
+		return super(CacheControlAdapter, self).send(*args, **kwargs)  # lgtm [py/super-not-enclosing-class]
 
 
 class HTTPCache:
